@@ -21,12 +21,13 @@ import sys
 import tarfile
 
 from reprounzip.common import load_config as load_config_file
+from reprounzip.main import unpackers
 from reprounzip.unpackers.common import load_config, COMPAT_OK, COMPAT_MAYBE, \
     COMPAT_NO, shell_escape
 from reprounzip.utils import iteritems, hsize
 
 
-def print_info(args, unpackers):
+def print_info(args):
     """Writes out some information about a pack file.
     """
     pack = Path(args.pack[0])
@@ -186,10 +187,7 @@ def showfiles(args):
             if len(runs) > 1:
                 print("  Run %d:" % i)
             for input_name, path in iteritems(run['input_files']):
-                if args.verbosity >= 2:
-                    print("    %s (%s)" % (input_name, path))
-                else:
-                    print("    %s" % input_name)
+                print("    %s (%s)" % (input_name, path))
                 if input_files.get(input_name) is not None:
                     assigned = PosixPath(input_files[input_name])
                 else:
@@ -201,10 +199,7 @@ def showfiles(args):
             if len(runs) > 1:
                 print("  Run %d:" % i)
             for output_name, path in iteritems(run['output_files']):
-                if args.verbosity >= 2:
-                    print("    %s (%s)" % (output_name, path))
-                else:
-                    print("    %s" % output_name)
+                print("    %s (%s)" % (output_name, path))
 
     else:  # pack.is_file()
         # Reads info from a pack file
@@ -215,17 +210,27 @@ def showfiles(args):
             if len(runs) > 1:
                 print("  Run %d:" % i)
             for input_name, path in iteritems(run['input_files']):
-                if args.verbosity >= 2:
-                    print("    %s (%s)" % (input_name, path))
-                else:
-                    print("    %s" % input_name)
+                print("    %s (%s)" % (input_name, path))
 
         print("Output files:")
         for i, run in enumerate(runs):
             if len(runs) > 1:
                 print("  Run %d:" % i)
             for output_name, path in iteritems(run['output_files']):
-                if args.verbosity >= 2:
-                    print("    %s (%s)" % (output_name, path))
-                else:
-                    print("    %s" % output_name)
+                print("    %s (%s)" % (output_name, path))
+
+
+def setup_info(parser, **kwargs):
+    """Prints out some information about a pack
+    """
+    parser.add_argument('pack', nargs=1,
+                        help="Pack to read")
+    parser.set_defaults(func=print_info)
+
+
+def setup_showfiles(parser, **kwargs):
+    """Prints out input and output file names
+    """
+    parser.add_argument('pack', nargs=1,
+                        help="Pack or directory to read from")
+    parser.set_defaults(func=showfiles)
