@@ -303,7 +303,7 @@ class FileUploader(object):
 
                 if temp is not None:
                     temp.remove()
-                    del self.input_files[input_name]
+                    self.input_files.pop(input_name, None)
                 else:
                     self.input_files[input_name] = local_path.absolute().path
         finally:
@@ -426,6 +426,8 @@ def get_runs(runs, selected_run, cmdline):
     """
     if selected_run is None and len(runs) == 1:
         selected_run = 0
+    elif selected_run is not None:
+        selected_run = int(selected_run)
 
     # --cmdline without arguments: display the original command-line
     if cmdline == []:
