@@ -91,8 +91,9 @@ def write_dict(filename, dct, type_):
 def read_dict(filename, type_):
     with filename.open('rb') as fp:
         dct = pickle.load(fp)
-    if type is not None:
-        assert dct['unpacker'] == type_
+    if type_ is not None and dct['unpacker'] != type_:
+        raise ValueError("Wrong unpacker used: %s != %s" % (dct['unpacker'],
+                                                            type_))
     return dct
 
 
@@ -716,7 +717,7 @@ def setup_installpkgs(parser):
     return {'test_compatibility': test_same_pkgmngr}
 
 
-def setup_directory(parser):
+def setup_directory(parser, **kwargs):
     """Unpacks the files in a directory and runs with PATH and LD_LIBRARY_PATH
 
     setup       creates the directory (needs the pack filename)
@@ -784,7 +785,7 @@ def chroot_setup(args):
         chroot_mount(args)
 
 
-def setup_chroot(parser):
+def setup_chroot(parser, **kwargs):
     """Unpacks the files and run with chroot
 
     setup/create    creates the directory (needs the pack filename)
